@@ -9,6 +9,7 @@
 """
 import bootstrap
 import debug
+import facter_config
 import subprocess
 import os
 import uuid
@@ -296,6 +297,8 @@ def make(n, q, k, args):
         deploy_files[node] = bootstrap.compose(node, data_path, scenario, initial_config_meta)
         dprint(node + 'deploy:\n' + deploy_files[node])
 
+    fact_exports = facter_config.create(initial_config_meta)
+    dprint("Fact exports:" + fact_exports)
     dprint("Deploy Files: " + str(deploy_files))
 
     user_config_yaml = yaml.dump(hiera_config_meta, default_flow_style=False)
@@ -324,6 +327,7 @@ def make(n, q, k, args):
                                u'/root/user.yaml'   : user_config_yaml,
                                u'/root/config.yaml' : initial_config_yaml,
                                u'/root/global.yaml' : global_config_yaml},
+                               u'/root/fact_exports': fact_exports},
                         meta={'ci_test_id' : test_id}
                         )
 
